==> apache-opennlp_1.9.4.orig.tar.gz: apache-opennlp-1.9.4-src/opennlp-tools/src/test/java/opennlp/tools/util/featuregen/POSTaggerNameFeatureGeneratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.util.featuregen;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.junit.Assert;
import org.junit.Test;

import opennlp.tools.postag.POSTaggerMETest;
import opennlp.tools.util.model.ModelType;

public class POSTaggerNameFeatureGeneratorTest {


  @Test
  public void testFeatureGeneration() throws IOException {
    POSTaggerNameFeatureGenerator fg = new POSTaggerNameFeatureGenerator(
        POSTaggerMETest.trainPOSModel(ModelType.MAXENT));

    String[] tokens = {"Hi", "Mike", ",", "it", "'s", "Stefanie", "Schmidt", "."};
    for (int i = 0; i < tokens.length; i++) {
      List<String> feats = new ArrayList<>();
      fg.createFeatures(feats, tokens, i, null);
      Assert.assertTrue(feats.get(0).startsWith("pos="));
    }
  }
}

==> apache-opennlp_2.1.0.orig.tar.gz: apache-opennlp-2.1.0-src/opennlp-tools/src/test/java/opennlp/tools/util/featuregen/POSTaggerNameFeatureGeneratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.util.featuregen;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import opennlp.tools.postag.POSTaggerMETest;
import opennlp.tools.util.model.ModelType;

public class POSTaggerNameFeatureGeneratorTest {


  @Test
  void testFeatureGeneration() throws IOException {
    POSTaggerNameFeatureGenerator fg = new POSTaggerNameFeatureGenerator(
        POSTaggerMETest.trainPOSModel(ModelType.MAXENT));

    String[] tokens = {"Hi", "Mike", ",", "it", "'s", "Stefanie", "Schmidt", "."};
    for (int i = 0; i < tokens.length; i++) {
      List<String> feats = new ArrayList<>();
      fg.createFeatures(feats, tokens, i, null);
      Assertions.assertTrue(feats.get(0).startsWith("pos="));
    }
  }
}
